;; Akira-Kaze Special Edition


;(set-default-font "BDFFont")
;; For some Free and High quality lisp sources...
(setq load-path (cons (expand-file-name "~/in_vitro/emacs/") load-path))
(setq load-path (cons (expand-file-name "~/elisp/") load-path))

(load "fenjin.el")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Emacs and Other Info files
(require 'info)
(setq Info-default-directory-list
	(cons (expand-file-name "~/in_vitro/info/") Info-default-directory-list))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; repeat function customization
;;
(setq repeat-message-function 'ignore)
;; (real repeat)
(defun my-repeat (arg)
	(interactive "p")
	(unless (eq real-last-command this-command)
		(let ((i 0))
			(while (< i arg)
				(repeat 1)
				(setq i (1+ i))))))
(global-set-key "\C-z" 'my-repeat)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Auto Save Feature Modification
;;
;; NOT Use Auto Save Feature
(setq auto-save-default nil)
(setq auto-save-interval 0)
(setq auto-save-timeout 0)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Backup File Feature Modification
;;
;; NOT Create Backup File when file saved first time
(setq make-backup-files nil)

;; NOTICE: Backup File and Auto Save is NOT SAME!!
;; Backup File is created as '***.**~', when the file is
;;  saved first time.
;; Auto Save is the feature which saves file as '#***.**#'.


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Coding-System Modification
;;
;; Enforcing coding-system to EUC.
(set-language-environment "Japanese")
(set-buffer-file-coding-system 'euc-jp-unix)
(set-terminal-coding-system 'euc-jp-unix)
(set-keyboard-coding-system 'euc-jp-unix)
(setq-default default-buffer-file-coding-system 'euc-jp-unix)

;; For PCL-CVS Coding System
(modify-coding-system-alist 'process "cvs" '(undecided . euc-jp))

;; Enforce Don't use auto coding decision system
(setq auto-coding-regexp-alist nil)		
(setq auto-coding-alist nil)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Whether on X or Terminal
;;
(cond
 ((eq window-system 'x)
  ;; When running on X 
  (set-face-foreground 'modeline "white")
  (set-face-background 'modeline "black")
  (set-scroll-bar-mode t);;nil)	;; Disable X Scroll Bar
  (tool-bar-mode -1) ;; Disable Tool bar
  (setq 
   default-frame-alist '(append
			 ((font . "fontset-standard")
			  default-frame-alist)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Delete and Backspace and C-h Modification
;;
;; Switch Delete and Backspace Key Feature following Running Mode( X? or Terminal?)
(cond
 ((eq window-system 'x)
  ;; On X, key code system can understand C-h and Backspace key.
  ;; So, here I only modify delete key as 'delete-char feature.
  (global-set-key [delete] 'delete-char))
 (t
  ;; When running on any terminal (e.g. emacs -nw)
  ;; On Terminal, delete key code is C-?, so, I simply modified delete key as C-d.
  (keyboard-translate ?\C-? ?\C-d)
  ;; On Terminal, Backspace key-code is same as C-h.
  ;; So, I modified C-h(as, Backspace) to delete-backward-char
  (global-set-key "\C-h" 'delete-backward-char)
))

;; Independant from X or Terminal
(setq visible-bell t) ;; Enable Visual Bell
(menu-bar-mode -1) ;; Disable Menu bar (on terminal or X)
(global-set-key "\C-\\" 'help-for-help) ;; C-\ as 'help-for-help command.
(line-number-mode t) ;; Display line number
(column-number-mode t) ;; Display column number
(global-font-lock-mode t) ;; Font-Lock mode
;; Use fast-lock-mode to display faster.
(setq font-lock-support-mode 'fast-lock-mode)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Basical Edit Feature Modification
;; (tabs, indents, wordwraps,etc. independant from Major Mode)
;;
;; Tab Modification
(setq-default tab-width 4)
(setq-default default-tab-width 4)
;;
;;(require 'autoinsert)
;; Word Wrap OFF ...No!! Word Wrap ON
;; ...I thought so many things. and I decided that I use default settings.
;; So, I commented out under 2 lines.
;;(setq-default truncate-partial-width-windows t)
(setq-default truncate-partial-width-windows nil)
;;(setq-default truncate-lines t)
;;
;; Region Mark Visualization On.
(setq-default transient-mark-mode t)
;; 
;; Jump to Specified Line Command Key bindings.(like vi editor)
(global-set-key "\C-x:" 'goto-line)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Scroll Feature Modification
;;
;; Set Scroll step to 1.
(setq scroll-step 1)
;; Don't make new line when cursor is end of buffer.
(setq next-line-add-newlines nil)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; ENFORCE Fundemenntal Mode!!!
;;
(setq auto-mode-alist nil)
(setq interpreter-mode-alist nil)
(setq auto-mode-alist (append
	'(
		("\\.el\\'" . emacs-lisp-mode)
		("\\.l\\'"	. lisp-mode)
		("\\.lisp\\'"	. lisp-mode)
		("\\`\\..*emacs\\'"	. emacs-lisp-mode)
		("[:/]_emacs\\'"	. emacs-lisp-mode)
		("\\.lsp\\'"	. lisp-mode)
;		("\\.tex\\'" . tex-mode) ;; for YaTeX binding.
		("\\.c\\'" . c++-mode)
		("\\.h\\'" . c++-mode)
		("\\.cc\\'" . c++-mode)
		("\\.hh\\'" . c++-mode)
		("\\.hpp\\'" . c++-mode)
		("\\.C\\'" . c++-mode)
		("\\.H\\'" . c++-mode)
		("\\.cpp\\'" . c++-mode)
		("\\.cxx\\'" . c++-mode)
		("\\.hxx\\'" . c++-mode)
		("\\.c\\+\\+\\'" . c++-mode)
		("\\.h\\+\\+\\'" . c++-mode)
		("\\(M\\|m\\|GNUm\\)akefile\\(\\.in\\)?\\'" . makefile-mode)
		("\\.am\\'" . makefile-mode)
		("\\.texinfo\\'" . texinfo-mode)
		("\\.te?xi\\'" . texinfo-mode)
		("\\.s\\'" . asm-mode)
		("\\.S\\'" . asm-mode)
		("\\.asm\\'" . asm-mode)
		("\\.s?html?\\'" . html-mode)
	)
	auto-mode-alist
))	

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Shell Mode Modification
;;
;; Disable regexp Current Directry Changing following Shell
(setq-default shell-cd-regexp nil)
(setq-default shell-pushd-regexp nil)
(setq-default shell-popd-regexp nil)
;; Enable Unvisible Password Input
(add-hook 'comint-output-filter-functions
          'comint-watch-for-password-prompt)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; for YaTeX Modification
;;
(setq auto-mode-alist
	(cons (cons "\\.tex$" 'yatex-mode) auto-mode-alist))
(autoload 'yatex-mode "yatex" "Yet Another LaTeX mode" t)

(setq load-path (cons (expand-file-name "~/in_vitro/emacs/yatex1.70") load-path))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Mew 3.2
;;
(autoload 'mew "mew" nil t)
(autoload 'mew-send "mew" nil t)
(setq mew-icon-directory (expand-file-name "~/in_vitro/etc/Mew"))
(setq load-path (cons (expand-file-name "~/in_vitro/emacs/mew") load-path))

;; Mew reads self configuration from $HOME/.mew.el
;; So, Mew's detailed configuration is Refered to .mew.el

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; For jaspace
;;
(require 'jaspace)
(setq jaspace-highlight-tabs t)

;; For pager.el
;;
(require 'pager)
(global-set-key "\C-v"	'pager-row-down)
(global-set-key "\M-v"	'pager-row-up)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; For Screen Lines (screen-lines.el)
;;
(require 'screen-lines)
(autoload 'screen-lines-mode "screen-lines"
	"Toggle Screen Lines minor mode for the current buffer." t)
(autoload 'turn-on-screen-lines-mode "screen-lines"
	"Turn on Screen Lines minor mode for the current buffer." t)
(autoload 'turn-off-screen-lines-mode "screen-lines"
	"Turn off Screen Lines minor mode for the current buffer." t)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; For mic-paren.el
;; (Hilighting brackets)
;;
(require 'mic-paren)
(global-unset-key "\M-)")
(global-set-key "\M-)" 'mic-paren-forward-sexp)
(global-unset-key "\M-(")
(global-set-key "\M-(" 'mic-paren-backward-sexp)
(paren-activate)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Dired Mode Customization
;;
;; Yet Not Completely...there are some misses...unknown...
;;

(defun dired-find-alternate-file()
	"In dired, visit this file or directory instead of the dired buffer."
	(interactive)
	(set-buffer-modified-p nil)
	(find-alternate-file (dired-get-filename)))

(add-hook 'dired-load-hook
	'(lambda ()
		(load-library "ls-lisp")
		(setq ls-lisp-dirs-first t)
		(setq dired-listing-switches "-AFl")
		(setq find-ls-option '("-exec ls -AFGl {} \\;" . "-AFGl"))
		(setq grep-find-command "find . -type f -print0 | xargs -0 -e grep -ns")
		(require 'wdired)
		))

;; narrowing enable
(put 'narrow-to-region 'disabled nil)

;; mode-line-format customization
(setq-default mode-line-format
	'("-"
		(line-number-mode "L%l-")
		(column-number-mode "C%c-")
		(-3 . "%p")
		"-"
		mode-line-mule-info
		mode-line-modified
		" "
		mode-line-buffer-identification
		" %[("
		mode-name
		mode-line-process
		"%n" ")%]-%-"
		))

(setq-default default-mode-line-format mode-line-format)
(global-unset-key "\M-k")

;; for Japanese Info Pages
(auto-compression-mode t)

;; for Emacs-Ceta 
(load "ceta.el")
(global-unset-key "\C-x\C-z")
(global-set-key "\C-x\C-z" 'ceta-menu)