(defun other-window-backward (&optional n)
  "Select Nth previous window."
  (interactive "P")
  (other-window (- (prefix-numeric-value n))))
(global-unset-key "\C-x\C-n")
(global-set-key "\C-x\C-n" 'other-window)
(global-unset-key "\C-x\C-p")
(global-set-key "\C-x\C-p" 'other-window-backward)

(defun point-to-top ()
  "Put point on top line of window."
  (interactive)
  (goto-char (point-min)))
(global-unset-key "\M-<")
(global-set-key "\M-<" 'point-to-top)
(defun point-to-bottom ()
  "Put point to bottom line of window."
  (interactive)
  (goto-char (point-max)))
(global-unset-key "\M->")
(global-set-key "\M->" 'point-to-bottom)

(defun read-only-if-symlink ()
  (if (file-symlink-p buffer-file-name)
	  (progn
		(setq buffer-read-only t)
		(message "File is a symlink"))))
(add-hook 'find-file-hooks 'read-only-if-symlink)

(defun visit-target-instead ()
  "Replace this buffer with a buffer visiting the link target."
  (interactive)
  (if buffer-file-name
	   (let ((target (file-symlink-p buffer-file-name)))
		 (if target
			 (find-alternate-file target)
		   (error "Not visiting a symlink")))
	   (error "Not visiting a file")))

(defun clobber-symlink ()
  "Replace sylink with a copy of the file."
  (interactive)
  (if buffer-file-name
	  (let ((target (file-symlink-p buffer-file-name)))
		(if target
			(if (yes-or-no-p (format "Replace %s with %s ?"
									 buffer-file-name
									 target))
				(progn
				  (delete-file buffer-file-name)
				  (write-file buffer-file-name)))
		  (error "Not visiting a symlink")))
	(error "Not visiting a file")))

(defadvice switch-to-buffer (before existing-buffer activate compile)
  "When interactive, switch to existing buffers only,
unless given a prefix argument."
  (interactive
   (list (read-buffer "Switch to buffer: "
					  (other-buffer)
					  (null current-prefix-arg)))))

(defvar unscroll-point (make-marker)
  "Cursor position for next call to 'unscroll'.")
(defvar unscroll-window-start (make-marker)
  "Window start fo next call to 'unscroll'.")
(defvar unscroll-hscroll nil
  "Hscroll for next call to 'unscroll'.")

(put 'scroll-up 'unscrollable t)
(put 'scroll-down 'unscrollable t)
(put 'scroll-left 'unscrollable t)
(put 'scroll-right 'unscrollable t)

(defun unscroll-maybe-remember ()
  (if (not (get last-command 'unscrollable))
	  (progn
		(set-marker unscroll-point (point))
		(set-marker unscroll-window-start (window-start))
		(setq unscroll-hscroll (window-hscroll)))))

(defadvice scroll-up (before remember-for-unscroll activate compile)
  "Remember where we started from , for 'unscroll'."
  (unscroll-maybe-remember))
(defadvice scroll-down (before remember-for-unscroll activate compile)
  "Remember where we started from , for 'unscroll'."
  (unscroll-maybe-remember))
(defadvice scroll-left (before remember-for-unscroll activate compile)
  "Remember where we started from , for 'unscroll'."
  (unscroll-maybe-remember))
(defadvice scroll-right (before remember-for-unscroll activate compile)
  "Remember where we started from , for 'unscroll'."
  (unscroll-maybe-remember))

(defun unscroll ()
  "Jump to location specified by 'unscroll-to'."
  (interactive)
  (if (not unscroll-point)
	  (error "Cannot unscroll yet"))
  (goto-char unscroll-point)
  (set-window-start nil unscroll-window-start)
  (set-window-hscroll nil unscroll-hscroll))

